@@ -1,6 +1,7 @@
 from aws_cdk import (
     Stack,
-    aws_pinpoint as pinpoint
+    aws_pinpoint as pinpoint,
+    aws_s3_assets as Asset
 ) 
 from constructs import Construct 
 
@@ -13,9 +14,13 @@ import base64
 
 def get_apns_certificate(cert_path, cert_pw):
     p12 = crypto.load_pkcs12(open(cert_path, 'rb').read(), cert_pw)
-    pem = crypto.dump_certificate(crypto.FILETYPE_PEM, p12.get_certificate())  
-    cert_str = pem.decode("utf-8").replace("\n","\\n") 
-    return pem.decode("ascii")
+    pem = crypto.dump_certificate(crypto.FILETYPE_PEM, p12.get_certificate())   
+    return pem
+
+def get_apns_private_key(cert_path, cert_pw):
+    p12 = crypto.load_pkcs12(open(cert_path, 'rb').read(), cert_pw)
+    pem = crypto.dump_privatekey(crypto.FILETYPE_PEM, p12.get_privatekey())   
+    return pem
 
 
 class NotificationStack(Stack): 
@@ -29,12 +34,15 @@ class NotificationStack(Stack):
         print(apns_certificate)
         print(apns_private_key)
 
+        directory_asset = Asset(self, "CERT", path="/Users/m1pro/Downloads/Certificates.cer")
+
+
         cfn_aPNSSandbox_channel = pinpoint.CfnAPNSSandboxChannel(self, "{}-apns-sandbox".format(pinpoint_app_name),
             application_id=pinpoint_app.ref,
 
             # the properties below are optional
             bundle_id=apns_bundle_id,
-            certificate=apns_certificate,
+            certificate=directory_asset,
             default_authentication_method="certificate", 
             enabled=True,
             private_key=apns_private_key,
